;rbsp_efw_position_velocity_crib

;Loads and plots RBSP (Van Allen probes) position and velocity data
;	MLT
;	Mlat
;	Lshell
;	Position (GSE)
;	Velocity (GSE)
;
;Need to have the SPICE ICY software package installed
;
;
;Written by Aaron Breneman, UMN, Dec 2012
;			email: awbrenem@gmail.com





; initialize RBSP environment
	rbsp_efw_init
	!rbsp_efw.user_agent = ''


; set desired probe
	probe = 'a'


; set time of interest to a single day
	date = '2012-10-13'	; UTC.
	duration = 1 ; days.
	timespan, date, duration



	integration=0 ; for looking at integration data
	get_support_data = 0 ; 0=no, 1=yes



	type='calibrated' ; use ADC (raw) numbers or physical (calibrated) units?


	;Load spice predicted values. Override with actual values if they exist
	;rbsp_load_spice_predict
	rbsp_load_spice_kernels



	;Load state data
	rbsp_load_spice_state,probe='a',coord='gse',/no_spice_load  
	rbsp_load_spice_state,probe='b',coord='gse',/no_spice_load  
	
	get_data,'rbspa_state_pos_gse',data=pos_gse_a
	get_data,'rbspb_state_pos_gse',data=pos_gse_b


	;Create position and velocity magnitude variables
	get_data,'rbspa_state_vel_gse',data=vela
	get_data,'rbspb_state_vel_gse',data=velb
	
	vmaga = sqrt(vela.y[*,0]^2 + vela.y[*,1]^2 + vela.y[*,2]^2)
	vmagb = sqrt(velb.y[*,0]^2 + velb.y[*,1]^2 + velb.y[*,2]^2)
	
	store_data,'vmag_a',data={x:vela.x,y:vmaga}
	store_data,'vmag_b',data={x:velb.x,y:vmagb}
	

	if probe eq 'a' then pos_gse = pos_gse_a else pos_gse = pos_gse_b
	rad = sqrt(pos_gse.y[*,0]^2 + pos_gse.y[*,1]^2 + pos_gse.y[*,2]^2)/6370.


	store_data,'radius',data={x:pos_gse.x,y:rad}
	options,'rbsp'+probe+'_state_pos_gse','panel_size',1
	options,'rbsp'+probe+'_state_vel_gse','panel_size',1
	options,'radius','panel_size',0.6
	options,'radius','ytitle','Rad!C[RE]'
	


	cotrans,'rbspa_state_pos_gse','rbspa_state_pos_gsm',/GSE2GSM	
	cotrans,'rbspb_state_pos_gse','rbspb_state_pos_gsm',/GSE2GSM	

	cotrans,'rbspa_state_vel_gse','rbspa_state_vel_gsm',/GSE2GSM	
	cotrans,'rbspb_state_vel_gse','rbspb_state_vel_gsm',/GSE2GSM	





;Calculate GSE separation b/t sc
	
	;Interpolate to get GSE pos of both sc on the same times.
	tinterpol_mxn,'rbspa_state_pos_gse',pos_gse.x,newname='rbspa_state_pos_gse2'	
	tinterpol_mxn,'rbspb_state_pos_gse',pos_gse.x,newname='rbspb_state_pos_gse2'	
	
	
	get_data,'rbspa_state_pos_gse2',data=pos_gse_a
	get_data,'rbspb_state_pos_gse2',data=pos_gse_b

	
	dx = (pos_gse_a.y[*,0] - pos_gse_b.y[*,0])/1000.
	dy = (pos_gse_a.y[*,1] - pos_gse_b.y[*,1])/1000.
	dz = (pos_gse_a.y[*,2] - pos_gse_b.y[*,2])/1000.

	sc_sep = sqrt(dx^2 + dy^2 + dz^2)

	store_data,'sc_sep',data={x:pos_gse.x,y:sc_sep}
	options,'sc_sep','labflag',0
	options,'sc_sep','ytitle','SC GSE!Cabsolute!Cseparation!Cx1000 km'

	store_data,'gse_sep',data={x:pos_gse.x,y:[[dx],[dy],[dz]]}
	options,'gse_sep','labels',['dx gse','dy gse','dz gse']
	options,'gse_sep','ytitle','SC GSE!Cseparation!Cx1000 km'





;Calculate L-shell

	;Position data must be in km
	ttrace2equator,'rbspa_state_pos_gsm',newname='rbspa_out_foot',/km
	ttrace2equator,'rbspb_state_pos_gsm',newname='rbspb_out_foot',/km
	

	get_data,'rbspa_out_foot',data=d
	Lshell_a = sqrt(d.y[*,0]^2 + d.y[*,1]^2 + d.y[*,2]^2)/6370.
	get_data,'rbspb_out_foot',data=d
	Lshell_b = sqrt(d.y[*,0]^2 + d.y[*,1]^2 + d.y[*,2]^2)/6370.

	if probe eq 'a' then Lshell = Lshell_a else Lshell = Lshell_b


	store_data,'lshell',data={x:pos_gse.x,y:lshell}
	options,'lshell','format','(f5.1)'
	options,'lshell','ytitle','Lshell'



;Calculate magnetic latitude	

	get_data,'rbspa_state_pos_gsm',data=pos_gsm_a
	get_data,'rbspb_state_pos_gsm',data=pos_gsm_b

	
	dr2a = sqrt(pos_gsm_a.y[*,0]^2 + pos_gsm_a.y[*,1]^2)
	dz2a = pos_gsm_a.y[*,2]
	dr2b = sqrt(pos_gsm_b.y[*,0]^2 + pos_gsm_b.y[*,1]^2)
	dz2b = pos_gsm_b.y[*,2]

	mlat_a = atan(dz2a,dr2a)
	mlat_b = atan(dz2b,dr2b)
	
	if probe eq 'a' then mlat = mlat_a else mlat = mlat_b


	store_data,'mlat',data={x:pos_gse.x,y:mlat/!dtor}
	options,'mlat','format','(f5.1)'        
	options,'mlat','ytitle','mlat'
	
	

;Calculate MLT
	
	angle_tmp = atan(pos_gse_a.y[*,1],pos_gse_a.y[*,0])/!dtor
	goo = where(angle_tmp lt 0.)
	if goo[0] ne -1 then angle_tmp[goo] = 360. - abs(angle_tmp[goo])
	angle_rad_a = angle_tmp * 12/180. + 12.
	goo = where(angle_rad_a ge 24.)
	if goo[0] ne -1 then angle_rad_a[goo] = angle_rad_a[goo] - 24

	angle_tmp = atan(pos_gse_b.y[*,1],pos_gse_b.y[*,0])/!dtor
	goo = where(angle_tmp lt 0.)
	if goo[0] ne -1 then angle_tmp[goo] = 360. - abs(angle_tmp[goo])
	angle_rad_b = angle_tmp * 12/180. + 12.
	goo = where(angle_rad_b ge 24.)
	if goo[0] ne -1 then angle_rad_b[goo] = angle_rad_b[goo] - 24

	if probe eq 'a' then angle_rad = angle_rad_a else angle_rad = angle_rad_b
	
	
	store_data,'mlt',data={x:pos_gse.x,y:angle_rad}




	



;Find differences in MLT and L b/t the two sc
	store_data,'mlt_a',data={x:pos_gse_a.x,y:angle_rad_a}
	store_data,'lshell_a',data={x:pos_gse_a.x,y:lshell_a}
	store_data,'mlat_a',data={x:pos_gse_a.x,y:mlat_a/!dtor}

	store_data,'mlt_b',data={x:pos_gse_b.x,y:angle_rad_b}
	store_data,'lshell_b',data={x:pos_gse_b.x,y:lshell_b}
	store_data,'mlat_b',data={x:pos_gse_b.x,y:mlat_b/!dtor}
	


	;Interpolate to get GSE pos of both sc on the same times.
	tinterpol_mxn,'mlt_a',pos_gse.x,newname='mlt_a2'
	tinterpol_mxn,'mlt_b',pos_gse.x,newname='mlt_b2'	
	dif_data,'mlt_a2','mlt_b2',newname='mlt_diff'

	tinterpol_mxn,'lshell_a',pos_gse.x,newname='lshell_a2'
	tinterpol_mxn,'lshell_b',pos_gse.x,newname='lshell_b2'	
	dif_data,'lshell_a2','lshell_b2',newname='lshell_diff'

	tinterpol_mxn,'mlat_a',pos_gse.x,newname='mlat_a2'
	tinterpol_mxn,'mlat_b',pos_gse.x,newname='mlat_b2'	
	dif_data,'mlat_a2','mlat_b2',newname='mlat_diff'


	options,'mlat_a2','ytitle','MLATa!Chours'
	options,'mlat_b2','ytitle','MLATb!Chours'
	options,'mlt_diff','ytitle','MLTa-!CMLTb!Chours'
	options,'lshell_diff','ytitle','LSHELLa-!CLSHELLb'
	options,'mlat_diff','ytitle','MLATa-!CMLATb!Cdegrees'
	options,'rbspa_state_vel_gse','ytitle','RBSPa!Cvelocity!CGSE'
	options,'rbspb_state_vel_gse','ytitle','RBSPb!Cvelocity!CGSE'


	ylim,'mlat_diff',-10,10
	ylim,'mlt_diff',-5,5

	options,'vmag_a','ytitle','|V| RBSPa!Ckm/s'
	options,'vmag_b','ytitle','|V| RBSPb!Ckm/s'





;Create x-axis labels for the plots
	var_label = ['lshell','mlat','mlt']





;Plot various quantities

	tplot_options,'title','rbsp position data - ' + date		


	;Plot position quantities
	tplot,['rbspa_state_pos_gse',$
		   'rbspb_state_pos_gse',$
		   'rbspa_state_pos_gsm',$
		   'rbspb_state_pos_gsm'],$ 
			var_label = var_label


	tplot,['mlat_a2',$
		   'mlat_b2',$
		   'lshell_a2',$
		   'lshell_b2',$
		   'mlt_a2',$
		   'mlt_b2'],$ 
			var_label = var_label



	
	;Plot velocity quantities
	tplot,['vmag_a',$
		   'rbspa_state_vel_gse',$
		   'rbspa_state_vel_gsm',$
		   'vmag_b',$
		   'rbspb_state_vel_gse',$
		   'rbspb_state_vel_gsm'],$ 
			var_label = var_label


	;Plot separations b/t sc
	tplot,['sc_sep',$
		   'gse_sep',$
		   'mlt_diff',$
		   'lshell_diff',$
		   'mlat_diff'],$ 
			var_label = var_label




	






;Plot to postscript
	title = prefix + 'position'
	print,'BEGIN ' + title + ' ' + systime()
	popen,savedir1 + title + '.ps'
		!p.charsize = charsz_plot
		tplot_options,'title','rbsp position data - ' + date		
		tplot,['rbspa_state_pos_gse',$
			   'rbspb_state_pos_gse',$
			   'rbspa_state_pos_gsm',$
			   'rbspb_state_pos_gsm'],$ 
				var_label = var_label

	pclose
	!p.charsize = charsz_win



endif





