;Crib sheet for calling rbsp_poynting_flux.pro

;Procedure: load EMFISIS data in GSE. 
;			Transform EMFISIS GSE -> MGSE
;			Load EFW despun waveform data in MGSE
;			Call Poynting flux program

;Created by Aaron W Breneman, UMN awbrenem@gmail.com
;


rbsp_efw_init
!rbsp_efw.user_agent = ''   ;for faster data downloads

date = '2012-10-13'
timespan,date
probe='a'




;--------------------------------------------------------------------------------
;Find the GSE coordinates of the sc spin axis. This will be used to transform the 
;Mag data from GSE -> MGSE coordinates
;--------------------------------------------------------------------------------


time2=time_double(date) ; first get unix time double for beginning of day

;Grab first and last time of day
time2 = [time2,time2+86399.]


;	time=time+dindgen(ntimes) ; turn it into a full day of unix times @ 1s cadence
time3=time_string(time2, prec=6) ; turn it back into a string for ISO conversion
strput,time3,'T',10 ; convert TPLOT time string 'yyyy-mm-dd/hh:mm:ss.msec' to ISO 'yyyy-mm-ddThh:mm:ss.msec'
cspice_str2et,time3,et2 ; convert ISO time string to SPICE ET

;Get rotation matrix to transform from science coord to GSE
cspice_pxform,'RBSP'+strupcase(probe)+'_SCIENCE','GSE',et2[0],pxform1
cspice_pxform,'RBSP'+strupcase(probe)+'_SCIENCE','GSE',et2[1],pxform2

wsc1 = dblarr(3)
wsc1[2] = 1d
wsc_GSE = dblarr(3)

;Calculate the spacecraft spin axis direction in GSE
wsc_GSE = pxform1 ## wsc1  ;start of day




;------------------------------------------------------
;Get EMFISIS mag data in GSE
;------------------------------------------------------

rbsp_load_emfisis_quicklook,probe=probe,datatype='1sec-gse'


;Transform mag data from GSE -> MGSE
rbsp_gse2mgse,'rbsp'+probe+'_mag_gse_1sec',reform(wsc_GSE),newname='Mag_mgse'




;----------------------------------------------------------
;Get Esvy data in MGSE 
;----------------------------------------------------------


;rbsp_load_spice_predict
rbsp_load_spice_kernels

rbsp_load_efw_esvy_mgse,probe=probe,/no_spice_load

get_data,'rbspa_efw_esvy_X_MGSE',data=d1
get_data,'rbspa_efw_esvy_Y_MGSE',data=d2
get_data,'rbspa_efw_esvy_Z_MGSE',data=d3



store_data,'rbspa_efw_esvy_MGSE',data={x:d1.x,y:[[d1.y],[d2.y],[d3.y]]}


;----------------------------------------------------------
;Get Poynting flux
;----------------------------------------------------------


Thigh = 40.  ;seconds
Tlow = 1. 

rbsp_poynting_flux,'Mag_mgse','rbspa_efw_esvy_MGSE',Tlow,Thigh


;----------------------------------------------------------
;Plot various quantities
;----------------------------------------------------------


 ;Ew_pflux                                           
 ;Bw_pflux                                           
 ;pflux_nospinaxis_perp                              
 ;pflux_nospinaxis_para                              
 ;pflux                                              
 ;pflux_nospinaxis_perp_iono                         
 ;pflux_nospinaxis_para_iono                         
 ;pflux_iono                                         
 ;Ew_pflux_p1                                        
 ;Ew_pflux_p2                                        
 ;Ew_pflux_p3                                        
 ;Bw_pflux_p1                                        
 ;Bw_pflux_p2                                        
 ;Bw_pflux_p3                                        
 ;pflux_p1                                           
 ;pflux_p2                                           
 ;pflux_Bo                                           
 ;pflux_iono_p1                                      
 ;pflux_iono_p2                                      
 ;pflux_iono_Bo                                      





;compare pure to mixed pflux
tplot,['pflux_nospinaxis_perp','pflux_nospinaxis_para','pflux_p1','pflux_p2','pflux_Bo']


;compare E and B to Pflux

;Perp to field component
tplot,['pflux_nospinaxis_perp','Ew_pflux_p1','Bw_pflux_p3','Mag_mgse_DC_interp']

;Field aligned component
tplot,['pflux_nospinaxis_para','Ew_pflux_p1','Bw_pflux_p2','Mag_mgse_DC_interp']




